aboutsummaryrefslogtreecommitdiffstats
path: root/epan/address.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2012-10-23 21:19:02 +0000
committerGuy Harris <guy@alum.mit.edu>2012-10-23 21:19:02 +0000
commit7c76ad78d3d2f891a4765cf619257437710f676f (patch)
treec524f975c43a44baa0ec3d2de5499cf35b16a209 /epan/address.h
parent31f7fee054c96c66b5e33fdbbde28fa9330cefe3 (diff)
Add an AT_ value for 802.15.4 short addresses.
Note that, if you want EUI-64's to resolve the OUI in the display, hacking individual dissectors to do it themselves and use AT_STRINGZ is *not* the right way to do it. svn path=/trunk/; revision=45743
Diffstat (limited to 'epan/address.h')
-rw-r--r--epan/address.h41
1 files changed, 21 insertions, 20 deletions
diff --git a/epan/address.h b/epan/address.h
index e9626c27c8..8bdfebac45 100644
--- a/epan/address.h
+++ b/epan/address.h
@@ -38,26 +38,27 @@ extern "C" {
/* also be included in address_to_str_buf defined in to_str.c, for presentation purposes */
typedef enum {
- AT_NONE, /* no link-layer address */
- AT_ETHER, /* MAC (Ethernet, 802.x, FDDI) address */
- AT_IPv4, /* IPv4 */
- AT_IPv6, /* IPv6 */
- AT_IPX, /* IPX */
- AT_SNA, /* SNA */
- AT_ATALK, /* Appletalk DDP */
- AT_VINES, /* Banyan Vines */
- AT_OSI, /* OSI NSAP */
- AT_ARCNET, /* ARCNET */
- AT_FC, /* Fibre Channel */
- AT_SS7PC, /* SS7 Point Code */
- AT_STRINGZ, /* null-terminated string */
- AT_EUI64, /* IEEE EUI-64 */
- AT_URI, /* URI/URL/URN */
- AT_TIPC, /* TIPC Address Zone,Subnetwork,Processor */
- AT_IB, /* Infiniband GID/LID */
- AT_USB, /* USB Device address
- * (0xffffffff represents the host) */
- AT_AX25 /* AX.25 */
+ AT_NONE, /* no link-layer address */
+ AT_ETHER, /* MAC (Ethernet, 802.x, FDDI) address */
+ AT_IPv4, /* IPv4 */
+ AT_IPv6, /* IPv6 */
+ AT_IPX, /* IPX */
+ AT_SNA, /* SNA */
+ AT_ATALK, /* Appletalk DDP */
+ AT_VINES, /* Banyan Vines */
+ AT_OSI, /* OSI NSAP */
+ AT_ARCNET, /* ARCNET */
+ AT_FC, /* Fibre Channel */
+ AT_SS7PC, /* SS7 Point Code */
+ AT_STRINGZ, /* null-terminated string */
+ AT_EUI64, /* IEEE EUI-64 */
+ AT_URI, /* URI/URL/URN */
+ AT_TIPC, /* TIPC Address Zone,Subnetwork,Processor */
+ AT_IB, /* Infiniband GID/LID */
+ AT_USB, /* USB Device address
+ * (0xffffffff represents the host) */
+ AT_AX25, /* AX.25 */
+ AT_IEEE_802_15_4_SHORT /* IEEE 802.15.4 16-bit short address */
} address_type;
typedef enum {